@@ -5,8 +5,8 @@
 __AUTHOR__ = 'ugursogukpinar'
 
 __TMPFILES__ = {
-    'posix'  : '/tmp/VHCreator.conf',
-    'nt' : 'C:/tmp/VHCreator.conf'
+    'posix'  : '/tmp/VHCreator/VHCreator.conf',
+    'nt' : 'C:/tmp/VHCreator/VHCreator.conf'
 }
 
 __ERRORS__ = {
@@ -14,7 +14,7 @@ __ERRORS__ = {
     'conffilecantwrite' : 'Default configuration could not save to {0}'
 }
 
-__VERSION__ = '0.1.2'
+__VERSION__ = '0.1.3'
 
 import argparse,os,sys
 
@@ -28,8 +28,13 @@ class Arguments(object):
         parser.add_argument('-cf','--conf',help='VirtualHosts configuration file path.',default=False)
         parser.add_argument('-ho','--host', action="store_true" , help='With this option you can insert your server name into hosts file.',default=False)
         parser.add_argument('-v','--version',action="version", help="Version",version='%s' % (__VERSION__))
-        # To next version
-        # parser.add_argument('-g','--git',help='Git repostiroy url to clone given directory',default=False)
+
+
+        # git_parser = argparse.ArgumentParser(add_help=)
+        # git_parser.add_argument('-r','--repo',help='Git repository url to clone given directory',default=False)
+        #
+        # git_sub_parser = argparse.ArgumentParser(parents=[git_parser]);
+        # git_sub_parser.add_argument('--foldername',help="Foldername define which folder will use on cloning.")
         # parser.add_argument('-a','--alias', help='You can give an alias virtual host',default=False)
 
         self.args = parser.parse_args()
@@ -48,7 +53,7 @@ class Arguments(object):
             confFilePath = tmpFile.readline().strip()
             return confFilePath
         except:
-            self.returnError('conffilenotfound',(__TMPFILES__[os.name]))
+            self.returnError('conffilenotfound',list(__TMPFILES__[os.name]))
 
 
     def setConfFile(self,confFilePath):
@@ -62,12 +67,12 @@ class Arguments(object):
 
 
 
-    def returnError(self,errorcode,**kwargs):
+    def returnError(self,errorcode,*args):
         errorStr = __ERRORS__[errorcode]
 
-        if(len(kwargs)):
-            for arg in kwargs:
+        if(len(args)):
+            for arg in args:
                 errorStr.format(arg)
 
         print errorStr
-        sys.exit(1)
+        sys.exit(2) #Return with exit
